Type: Package
Package: gDR
Title: Umbrella package for R packages in the gDR suite
Version: 1.9.1
Date: 2025-10-30
Authors@R: c(
    person("Allison", "Vuong", , "vuong.allison@gene.com", role = "aut"),
    person("Bartosz", "Czech", role = "aut",
           comment = c(ORCID = "0000-0002-9908-3007")),
    person("Arkadiusz", "Gladki", role=c("cre", "aut"), email="gladki.arkadiusz@gmail.com",
           comment = c(ORCID = "0000-0002-7059-6378")),
    person("Marc", "Hafner", role = "aut",
           comment = c(ORCID = "0000-0003-1337-7598")),
    person("Dariusz", "Scigocki", role = "aut"),
    person("Janina", "Smola", role = "aut"),
    person("Sergiu", "Mocanu", role = "aut")
  )
Description: Package is a part of the gDR suite. It reexports functions from other packages
    in the gDR suite that contain critical processing functions and utilities.
    The vignette walks through the full processing pipeline for drug response analyses that
    the gDR suite offers.
License: Artistic-2.0
Depends: R (>= 4.2), gDRcore (>= 1.7.1), gDRimport (>= 1.7.1), gDRutils
        (>= 1.7.1)
Suggests: BiocStyle, BumpyMatrix, futile.logger, gDRstyle (>= 1.7.1),
        gDRtestData (>= 1.7.1), kableExtra, knitr, markdown, purrr,
        rmarkdown, SummarizedExperiment, testthat, yaml
URL: https://github.com/gdrplatform/gDR,
        https://gdrplatform.github.io/gDR/
BugReports: https://github.com/gdrplatform/gDR/issues
biocViews: Software, DataImport, ShinyApps
VignetteBuilder: knitr
ByteCompile: TRUE
LazyLoad: yes
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.1
SwitchrLibrary: gDR
DeploySubPath: gDR
Encoding: UTF-8
git_url: https://git.bioconductor.org/packages/gDR
git_branch: devel
git_last_commit: 9871bb8
git_last_commit_date: 2025-10-30
Repository: Bioconductor 3.23
Date/Publication: 2025-10-31
NeedsCompilation: no
Packaged: 2025-10-31 21:54:15 UTC; biocbuild
Author: Allison Vuong [aut],
  Bartosz Czech [aut] (ORCID: <https://orcid.org/0000-0002-9908-3007>),
  Arkadiusz Gladki [cre, aut] (ORCID:
    <https://orcid.org/0000-0002-7059-6378>),
  Marc Hafner [aut] (ORCID: <https://orcid.org/0000-0003-1337-7598>),
  Dariusz Scigocki [aut],
  Janina Smola [aut],
  Sergiu Mocanu [aut]
Maintainer: Arkadiusz Gladki <gladki.arkadiusz@gmail.com>
