# fix for the NOTE in R CMD CHECK
# (packages defined in  Depends must have records in NAMESPACE)
#' @importFrom gDRimport load_data
#' @importFrom gDRcore merge_data
#' @importFrom gDRutils fit_curves

#' @keywords internal
#' @return package help page
"_PACKAGE"
NULL
